@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tidal" "1.10.1"
+(define-package "tidal" "20250711.1955"
   "Interact with TidalCycles for live coding patterns."
   '((haskell-mode "16")
     (emacs        "25.1"))
